summaryrefslogtreecommitdiff
path: root/packages/taler-util/src/merchant-api-types.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/taler-util/src/merchant-api-types.ts')
-rw-r--r--packages/taler-util/src/merchant-api-types.ts14
1 files changed, 7 insertions, 7 deletions
diff --git a/packages/taler-util/src/merchant-api-types.ts b/packages/taler-util/src/merchant-api-types.ts
index d7a5cf576..9f00173f2 100644
--- a/packages/taler-util/src/merchant-api-types.ts
+++ b/packages/taler-util/src/merchant-api-types.ts
@@ -290,22 +290,22 @@ export interface ReserveStatusEntry {
active: boolean;
}
-export interface TipCreateConfirmation {
+export interface RewardCreateConfirmation {
// Unique tip identifier for the tip that was created.
- tip_id: string;
+ reward_id: string;
// taler://tip URI for the tip
- taler_tip_uri: string;
+ taler_reward_uri: string;
// URL that will directly trigger processing
// the tip when the browser is redirected to it
- tip_status_url: string;
+ reward_status_url: string;
- // when does the tip expire
- tip_expiration: AbsoluteTime;
+ // when does the reward expire
+ reward_expiration: AbsoluteTime;
}
-export interface TipCreateRequest {
+export interface RewardCreateRequest {
// Amount that the customer should be tipped
amount: AmountString;